package cn.estsh.i3plus.core.apiservice.controller.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ITaskTimeExpressionService;
import cn.estsh.i3plus.platform.common.convert.ConvertBean;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.TaskTimeExpression;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description : 系统时间表达式 服务
 * @Reference   :
 * @Author      : wei.peng
 * @Date        : 2018-10-22 16:58:43.838
 * @Modify      :
 **/
@RestController
@RequestMapping("/task-time-expression")
@Api(description = "系统时间表达式")
public class TaskTimeExpressionController {

    public static final Logger LOGGER = LoggerFactory.getLogger(TaskTimeExpressionController.class);

    @Autowired
    private ITaskTimeExpressionService taskTimeExpressionService;

    @PostMapping(value = "/insert")
    @ApiOperation(value = "新增系统时间表达式", notes = "系统时间表达式")
    public ResultBean insertTaskTimeExpression(TaskTimeExpression timeExpression) {
        try {
            // 数据校验
            ValidatorBean.beginValid(timeExpression)
                    .notNull("name", timeExpression.getName())
                    .notNull("timeExpression", timeExpression.getTimeExpression())
                    .notNull("timeDescription", timeExpression.getTimeDescription());

            ConvertBean.modelInitialize(timeExpression, AuthUtil.getSessionUser());

            timeExpression  = taskTimeExpressionService.insertTaskTimeExpression(timeExpression);

            return ResultBean.success("操作成功")
                    .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode())
                    .setResultObject(timeExpression);
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @PutMapping(value = "/update")
    @ApiOperation(value = "修改系统时间表达式", notes = "系统时间表达式")
    public ResultBean updateTaskTimeExpression(TaskTimeExpression timeExpression) {
        try {
            // 数据校验
            ValidatorBean.beginValid(timeExpression)
                    .notNull("id", timeExpression.getId())
                    .notNull("name", timeExpression.getName())
                    .notNull("timeExpression", timeExpression.getTimeExpression())
                    .notNull("timeDescription", timeExpression.getTimeDescription());

            ConvertBean.modelInitialize(timeExpression, AuthUtil.getSessionUser());

            taskTimeExpressionService.updateTaskTimeExpression(timeExpression);

            return ResultBean.success("操作成功")
                    .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode())
                    .setResultObject(timeExpression);
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @DeleteMapping(value = "/delete/{id}")
    @ApiOperation(value = "删除系统时间表达式", notes = "删除系统时间表达式")
    public ResultBean deleteTaskTimeExpression(@PathVariable("id") String id) {
        try {
            // 数据校验
            ValidatorBean.checkNotNull(id, "时间表达式id 不能为空");

            taskTimeExpressionService.deleteTaskTimeExpressionById(id);
            return ResultBean.success().setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @GetMapping(value = "/list")
    @ApiOperation(value = "查询时间表达式所有", notes = "查询所有系统时间表达式")
    public ResultBean findTaskTimeExpressionAll() {
        try {
            List<TaskTimeExpression> list = taskTimeExpressionService.findTaskTimeExpressionAll();
            return ResultBean.success("操作成功")
                    .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode())
                    .setResultList(list);
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @GetMapping(value = "/get/{id}")
    @ApiOperation(value = "查询系统时间表达式", notes = "查询根据ID查询系统时间表达式")
    public ResultBean getByTaskTimeExpressionId(@PathVariable("id") String id) {
        try {
            // 数据校验
            ValidatorBean.checkNotNull(id, "定时任务id 不能为空");

            TaskTimeExpression taskTimeExpression = taskTimeExpressionService.getTaskTimeExpressionById(id);

            return ResultBean.success("操作成功")
                    .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode())
                    .setResultObject(taskTimeExpression);
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }
}
