package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.IOrganizeService;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.ImppEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.Organize;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.i3plus.pojo.platform.repository.OrganizeRepository;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import org.aspectj.weaver.ast.Or;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 组织业务接口实现 
 * @Reference   :
 * @Author      : wei.peng
 * @Date        : 2018-10-22 16:58:42.957
 * @Modify      :
 **/
@Service
public class OrganizeServiceImpl implements IOrganizeService {

    public static final Logger LOGGER = LoggerFactory.getLogger(OrganizeServiceImpl.class);

    @Autowired
    private OrganizeRepository organizeRDao;

    @Override
    public void updateOrganize(Organize organize) {
        LOGGER.info("组织 ORGANIZE :{}", organize);

        if(organize.getParentId() != null){
            Organize org = getOrganizeById(organize.getParentId().toString());
            ValidatorBean.checkNotNull(org);

            organize.setRedParentName(org.getName());
        }

        organizeRDao.update(organize);
    }

    @Override
    public void updateOrganizeStatus(String id, int status, SessionUser user) {
        LOGGER.info("组织 ORGANIZE  id:{} status:{} user:{}", id,status,user);
        Organize organize = organizeRDao.getById(Long.parseLong(id));
        organize.setOrganizeStatusId(status);
        organize.setModifyUser(user.getUserName());
        organizeRDao.update(organize);
    }

    @Override
    public void deleteOrganizeById(String id) {
        LOGGER.info("组织 ORGANIZE Key:{}", id);
        long count = organizeRDao.findByPropertyCount("parentId", Long.parseLong(id));
        if (count >= 1) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION_DATA_NOT_EXIT.getCode())
                    .setErrorDetail("该数据有子集")
                    .setErrorSolution("请先删除子集在操作")
                    .build();
        }
        organizeRDao.deleteById(Long.parseLong(id));
    }


    @Override
    public Organize insertOrganize(Organize organize) {
        LOGGER.info("组织 ORGANIZE :{}", organize);

        if(organize.getParentId() != null){
            Organize org = getOrganizeById(organize.getParentId().toString());
            ValidatorBean.checkNotNull(org);

            organize.setRedParentName(org.getName());
        }
        return organizeRDao.insert(organize);
    }

    @Override
    public List<Organize> findOrganizeAll() {
        LOGGER.info("组织 ORGANIZE find All");
        return organizeRDao.findAll();
    }

    @Override
    public Organize getOrganizeById(String id) {
        LOGGER.info("组织 ORGANIZE find id:{}", id);
        return organizeRDao.getOne(Long.parseLong(id));
    }
}
