package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.IPositionService;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.common.PagerHelper;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.HqlPack;
import cn.estsh.i3plus.pojo.platform.bean.Position;
import cn.estsh.i3plus.pojo.platform.repository.PositionRepository;
import cn.estsh.i3plus.pojo.platform.sqlpack.CoreHqlPack;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.lang.reflect.Array;
import java.util.Arrays;
import java.util.List;

/**
 * @Description : 岗位服务接口实现
 * @Reference :
 * @Author : yunhao
 * @Date : 2018-10-19 16:36
 * @Modify :
 **/
@Service
public class PositionServiceImpl implements IPositionService {
    public static final Logger LOGGER = LoggerFactory.getLogger(PositionServiceImpl.class);

    @Autowired
    private PositionRepository positionRDao;

    @Override
    public Position insertPosition(Position position) {
        // 查询父级岗位名称
        if (position.getParentId() != null && position.getParentId() > 0) {
            LOGGER.info("岗位信息 POSITION parentId:{}", position.getParentId());
            Position parentPosition = positionRDao.getById(position.getParentId());
            ValidatorBean.checkNotNull(parentPosition);

            position.setRedParentName(parentPosition.getName());
        }

        // 添加岗位
        LOGGER.info("岗位信息 POSITION position:{}", position);
        return positionRDao.insert(position);
    }

    @Override
    public void updatePosition(Position position) {
        // 查询父级岗位名称
        if (position.getParentId() != null  && position.getParentId() > 0) {
            LOGGER.info("岗位信息 POSITION parentId:{}", position.getParentId());
            Position parentPosition = positionRDao.getById(position.getParentId());
            ValidatorBean.checkNotNull(parentPosition);

            position.setRedParentName(parentPosition.getName());
        }

        // 修改岗位信息
        LOGGER.info("岗位信息 POSITION position:{}", position);
        positionRDao.update(position);
    }

    @Override
    public void deletePositionById(String id) {
        // 查询是否存在子级
        LOGGER.info("岗位信息 POSITION id:{}", id);
        long positionCount = positionRDao.findByPropertyCount("parentId",Long.parseLong(id));
        if (positionCount >= 1) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.CORE.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("存在子节点无法删除！")
                    .setErrorSolution("请重新操作")
                    .build();
        }

        // 删除岗位信息
        LOGGER.info("岗位信息 POSITION id:{}", id);
        positionRDao.deleteById(Long.parseLong(id));
    }

    @Override
    public List listPosition() {
        LOGGER.info("岗位信息 Position list");
        return positionRDao.list();
    }

    @Override
    public Position getPositionById(String id) {
        LOGGER.info("岗位信息 根据Id查询岗位信息 id:{}", id);
        return positionRDao.getById(Long.parseLong(id));
    }

    @Override
    public ListPager findPositionByPager(Position position, Pager pager) {
        if (position == null) {
            pager = PagerHelper.getPager(pager, positionRDao.listCount());
            return new ListPager(positionRDao.listPager(pager),pager);
        } else {
            String hqlPack = CoreHqlPack.packHqlPosition(position);
            pager = PagerHelper.getPager(pager, positionRDao.findByHqlWhereCount(hqlPack));
            return new ListPager(positionRDao.findByHqlWherePage(hqlPack + position.getOrderByParam(),pager),pager);
        }
    }

    @Override
    public void deletePositionByIds(String[] ids) {
        long positionCount = positionRDao.findByHqlCount(CoreHqlPack.packHqlIds("id",ids));
        if (positionCount >= 1) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.CORE.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("存在子节点无法删除！")
                    .setErrorSolution("请重新操作")
                    .build();
        }else {
            for(String idStr : ids){
                positionRDao.deleteById(Long.parseLong(idStr));
            }
        }
    }

}
