package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysMessageService;
import cn.estsh.i3plus.pojo.platform.bean.Department;
import cn.estsh.i3plus.pojo.platform.bean.SysMessage;
import cn.estsh.i3plus.pojo.platform.bean.SysUser;
import cn.estsh.i3plus.pojo.platform.repository.SysMessageRepository;
import cn.estsh.i3plus.pojo.platform.repository.SysUserRepository;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 消息服务接口实现
 * @Reference :
 * @Author : yunhao
 * @Date : 2018-10-25 18:02
 * @Modify :
 **/
@Service
public class SysMessageServiceImpl implements ISysMessageService {
    public static final Logger LOGGER = LoggerFactory.getLogger(SysMessageServiceImpl.class);

    @Autowired
    public SysMessageRepository sysMessageRDao;

    @Autowired
    public SysUserRepository sysUserRDao;

    @Override
    public void insertSysMessage(SysMessage sysMessage) {
        // 查询接收人名称
        if (sysMessage.getMessageRecipientId() != null  && sysMessage.getMessageRecipientId() > 0) {
            LOGGER.info("用户信息 SYSUSER id:{}", sysMessage.getMessageRecipientId());
            SysUser acceptUser = sysUserRDao.getById(sysMessage.getMessageRecipientId());
            ValidatorBean.checkNotNull(acceptUser);

            sysMessage.setRedMessageRecipientName(acceptUser.getName());
        }

        LOGGER.info("系统信息 SYS_MESSAGE :{}",sysMessage);
        sysMessageRDao.insert(sysMessage);
    }

    @Override
    public void deleteSysMessageById(String id) {
        LOGGER.info("系统信息 SYS_MESSAGE id:{}",id);
        sysMessageRDao.deleteById(Long.parseLong(id));

    }

    @Override
    public void updateSysMessage(SysMessage sysMessage) {
        // 查询接收人名称
        if (sysMessage.getMessageRecipientId() != null  && sysMessage.getMessageRecipientId() > 0) {
            LOGGER.info("用户信息 SYSUSER id:{}", sysMessage.getMessageRecipientId());
            SysUser acceptUser = sysUserRDao.getById(sysMessage.getMessageRecipientId());
            ValidatorBean.checkNotNull(acceptUser);

            sysMessage.setRedMessageRecipientName(acceptUser.getName());
        }

        LOGGER.info("系统信息 SYS_MESSAGE :{}",sysMessage);
        sysMessageRDao.update(sysMessage);
    }

    @Override
    public List<SysMessage> listSysMessage() {
        LOGGER.info("系统信息 SYS_MESSAGE list");
        return sysMessageRDao.list();
    }

    @Override
    public SysMessage getSysMessageById(String id) {
        LOGGER.info("系统信息 SYS_MESSAGE id:{}",id);
        return sysMessageRDao.getById(Long.parseLong(id));
    }
}
